@@ -18,6 +18,7 @@ from typing import (
     Any,
     TypeVar,
     Union,
+    _AnnotatedAlias,  # type: ignore
     cast,
     overload,
 )
@@ -574,9 +575,9 @@ def field(
     graphql_type: Any | None = None,
     extensions: Sequence[FieldExtension] = (),
     pagination: bool | UnsetType = UNSET,
-    filters: type | UnsetType | None = UNSET,
-    order: type | UnsetType | None = UNSET,
-    ordering: type | UnsetType | None = UNSET,
+    filters: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    order: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    ordering: _AnnotatedAlias | type | UnsetType | None = UNSET,
     only: TypeOrSequence[str] | None = None,
     select_related: TypeOrSequence[str] | None = None,
     prefetch_related: TypeOrSequence[PrefetchType] | None = None,
@@ -603,9 +604,9 @@ def field(
     graphql_type: Any | None = None,
     extensions: Sequence[FieldExtension] = (),
     pagination: bool | UnsetType = UNSET,
-    filters: type | UnsetType | None = UNSET,
-    order: type | UnsetType | None = UNSET,
-    ordering: type | UnsetType | None = UNSET,
+    filters: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    order: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    ordering: _AnnotatedAlias | type | UnsetType | None = UNSET,
     only: TypeOrSequence[str] | None = None,
     select_related: TypeOrSequence[str] | None = None,
     prefetch_related: TypeOrSequence[PrefetchType] | None = None,
@@ -632,9 +633,9 @@ def field(
     graphql_type: Any | None = None,
     extensions: Sequence[FieldExtension] = (),
     pagination: bool | UnsetType = UNSET,
-    filters: type | UnsetType | None = UNSET,
-    order: type | UnsetType | None = UNSET,
-    ordering: type | UnsetType | None = UNSET,
+    filters: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    order: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    ordering: _AnnotatedAlias | type | UnsetType | None = UNSET,
     only: TypeOrSequence[str] | None = None,
     select_related: TypeOrSequence[str] | None = None,
     prefetch_related: TypeOrSequence[PrefetchType] | None = None,
@@ -660,9 +661,9 @@ def field(
     graphql_type: Any | None = None,
     extensions: Sequence[FieldExtension] = (),
     pagination: bool | UnsetType = UNSET,
-    filters: type | UnsetType | None = UNSET,
-    order: type | UnsetType | None = UNSET,
-    ordering: type | UnsetType | None = UNSET,
+    filters: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    order: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    ordering: _AnnotatedAlias | type | UnsetType | None = UNSET,
     only: TypeOrSequence[str] | None = None,
     select_related: TypeOrSequence[str] | None = None,
     prefetch_related: TypeOrSequence[PrefetchType] | None = None,
@@ -808,9 +809,9 @@ def connection(
     directives: Sequence[object] | None = (),
     extensions: Sequence[FieldExtension] = (),
     max_results: int | None = None,
-    filters: type | None = UNSET,
-    order: type | None = UNSET,
-    ordering: type | None = UNSET,
+    filters: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    order: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    ordering: _AnnotatedAlias | type | UnsetType | None = UNSET,
     only: TypeOrSequence[str] | None = None,
     select_related: TypeOrSequence[str] | None = None,
     prefetch_related: TypeOrSequence[PrefetchType] | None = None,
@@ -838,9 +839,9 @@ def connection(
     directives: Sequence[object] | None = (),
     extensions: Sequence[FieldExtension] = (),
     max_results: int | None = None,
-    filters: type | None = UNSET,
-    order: type | None = UNSET,
-    ordering: type | None = UNSET,
+    filters: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    order: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    ordering: _AnnotatedAlias | type | UnsetType | None = UNSET,
     only: TypeOrSequence[str] | None = None,
     select_related: TypeOrSequence[str] | None = None,
     prefetch_related: TypeOrSequence[PrefetchType] | None = None,
@@ -866,9 +867,9 @@ def connection(
     directives: Sequence[object] | None = (),
     extensions: Sequence[FieldExtension] = (),
     max_results: int | None = None,
-    filters: type | None = UNSET,
-    order: type | None = UNSET,
-    ordering: type | None = UNSET,
+    filters: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    order: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    ordering: _AnnotatedAlias | type | UnsetType | None = UNSET,
     only: TypeOrSequence[str] | None = None,
     select_related: TypeOrSequence[str] | None = None,
     prefetch_related: TypeOrSequence[PrefetchType] | None = None,
@@ -998,9 +999,9 @@ def offset_paginated(
     metadata: Mapping[Any, Any] | None = None,
     directives: Sequence[object] | None = (),
     extensions: Sequence[FieldExtension] = (),
-    filters: type | None = UNSET,
-    order: type | None = UNSET,
-    ordering: type | None = UNSET,
+    filters: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    order: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    ordering: _AnnotatedAlias | type | UnsetType | None = UNSET,
     only: TypeOrSequence[str] | None = None,
     select_related: TypeOrSequence[str] | None = None,
     prefetch_related: TypeOrSequence[PrefetchType] | None = None,
@@ -1027,9 +1028,9 @@ def offset_paginated(
     metadata: Mapping[Any, Any] | None = None,
     directives: Sequence[object] | None = (),
     extensions: Sequence[FieldExtension] = (),
-    filters: type | None = UNSET,
-    order: type | None = UNSET,
-    ordering: type | None = UNSET,
+    filters: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    order: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    ordering: _AnnotatedAlias | type | UnsetType | None = UNSET,
     only: TypeOrSequence[str] | None = None,
     select_related: TypeOrSequence[str] | None = None,
     prefetch_related: TypeOrSequence[PrefetchType] | None = None,
@@ -1054,9 +1055,9 @@ def offset_paginated(
     metadata: Mapping[Any, Any] | None = None,
     directives: Sequence[object] | None = (),
     extensions: Sequence[FieldExtension] = (),
-    filters: type | None = UNSET,
-    order: type | None = UNSET,
-    ordering: type | None = UNSET,
+    filters: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    order: _AnnotatedAlias | type | UnsetType | None = UNSET,
+    ordering: _AnnotatedAlias | type | UnsetType | None = UNSET,
     only: TypeOrSequence[str] | None = None,
     select_related: TypeOrSequence[str] | None = None,
     prefetch_related: TypeOrSequence[PrefetchType] | None = None,
