@@ -108,7 +108,7 @@ def _process_type(
         model_fields = [f for f in model_fields if f.name != "id"]
 
     existing_annotations = get_annotations(cls)
-    cls_annotations = cls.__dict__.get("__annotations__", {})
+    cls_annotations = cls.__dict__.get("__annotations__", {})  # noqa: RUF063
     cls.__annotations__ = cls_annotations
 
     for f in model_fields:
@@ -433,6 +433,7 @@ class StrawberryDjangoDefinition(Generic[_O, _M]):
 
 
 @dataclass_transform(
+    kw_only_default=True,
     order_default=True,
     field_specifiers=(
         StrawberryField,
@@ -504,6 +505,7 @@ def type(  # noqa: A001
 
 
 @dataclass_transform(
+    kw_only_default=True,
     order_default=True,
     field_specifiers=(
         StrawberryField,
@@ -548,6 +550,7 @@ def interface(
 
 
 @dataclass_transform(
+    kw_only_default=True,
     order_default=True,
     field_specifiers=(
         StrawberryField,
@@ -598,6 +601,7 @@ def input(  # noqa: A001
 
 
 @dataclass_transform(
+    kw_only_default=True,
     order_default=True,
     field_specifiers=(
         StrawberryField,
